==> aim-3.6.2.tar.gz: aim-3.6.2/aim/web/migrations/env.py <==
from __future__ import with_statement

import logging
import os
from logging.config import fileConfig

from alembic import context
from alembic.config import Config

from aim.web.configs import AIM_ENV_MODE_KEY
from aim.web.api.db import engine, config as api_config
from aim.web.api.dashboards import models
from aim.web.api.dashboard_apps import models
from aim.web.api.db import Base

# this is the Alembic Config object, which provides
# access to the values within the .ini file in use.
config = context.config

if os.getenv(AIM_ENV_MODE_KEY, 'prod') != 'prod':
    here = os.path.abspath(os.path.dirname(__file__))
    config = Config(os.path.join(here, 'alembic_dev.ini'))

# Interpret the config file for Python logging.
# This line sets up loggers basically.
fileConfig(config.config_file_name)
logger = logging.getLogger('alembic.env')

# add your model's MetaData object here
# for 'autogenerate' support
target_metadata = Base.metadata

# other values from the config, defined by the needs of env.py,
# can be acquired:
# my_important_option = config.get_main_option("my_important_option")
# ... etc.


def run_migrations_offline():
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an Engine, though an Engine is acceptable
    here as well.  By skipping the Engine creation
    we don't even need a DBAPI to be available.

    Calls to context.execute() here emit the given string to the
    script output.

    """
    url = api_config.SQLALCHEMY_DATABASE_URI
    context.configure(
        url=url, target_metadata=target_metadata, literal_binds=True
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online():
    """Run migrations in 'online' mode.

    In this scenario we need to create an Engine
    and associate a connection with the context.

    """

    # this callback is used to prevent an auto-migration from being generated
    # when there are no changes to the schema
    # reference: http://alembic.zzzcomputing.com/en/latest/cookbook.html
    def process_revision_directives(context, revision, directives):
        if getattr(config.cmd_opts, 'autogenerate', False):
            script = directives[0]
            if script.upgrade_ops.is_empty():
                directives[:] = []
                logger.info('No changes in schema detected.')

    connectable = engine

    with connectable.connect() as connection:
        context.configure(
            connection=connection,
            target_metadata=target_metadata,
            process_revision_directives=process_revision_directives
        )

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()

==> aim-3.14.2.tar.gz: aim-3.14.2/aim/web/migrations/env.py <==
from __future__ import with_statement

import logging
import os
from logging.config import fileConfig

from alembic import context
from alembic.config import Config

from aim.web.configs import AIM_ENV_MODE_KEY
from aim.web.api.db import engine
from aim.web.utils import get_db_url
from aim.web.api.dashboards import models
from aim.web.api.dashboard_apps import models
from aim.web.api.db import Base

# this is the Alembic Config object, which provides
# access to the values within the .ini file in use.
config = context.config

if os.getenv(AIM_ENV_MODE_KEY, 'prod') != 'prod':
    here = os.path.abspath(os.path.dirname(__file__))
    config = Config(os.path.join(here, 'alembic_dev.ini'))

# Interpret the config file for Python logging.
# This line sets up loggers basically.
fileConfig(config.config_file_name)
logger = logging.getLogger('alembic.env')

# add your model's MetaData object here
# for 'autogenerate' support
target_metadata = Base.metadata

# other values from the config, defined by the needs of env.py,
# can be acquired:
# my_important_option = config.get_main_option("my_important_option")
# ... etc.


def run_migrations_offline():
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an Engine, though an Engine is acceptable
    here as well.  By skipping the Engine creation
    we don't even need a DBAPI to be available.

    Calls to context.execute() here emit the given string to the
    script output.

    """
    context.configure(
        url=get_db_url(), target_metadata=target_metadata, literal_binds=True
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online():
    """Run migrations in 'online' mode.

    In this scenario we need to create an Engine
    and associate a connection with the context.

    """

    # this callback is used to prevent an auto-migration from being generated
    # when there are no changes to the schema
    # reference: http://alembic.zzzcomputing.com/en/latest/cookbook.html
    def process_revision_directives(context, revision, directives):
        if getattr(config.cmd_opts, 'autogenerate', False):
            script = directives[0]
            if script.upgrade_ops.is_empty():
                directives[:] = []
                logger.info('No changes in schema detected.')

    connectable = engine

    with connectable.connect() as connection:
        context.configure(
            connection=connection,
            target_metadata=target_metadata,
            process_revision_directives=process_revision_directives
        )

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()
